@@ -1,16 +1,6 @@
 from CFNetwork import *
 from PyObjCTools.TestSupport import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
 class TestCFFTPStream (TestCase):
 
     def testConstants(self):
